"""CLI parser"""
from optparse import OptionParser, OptionGroup
from conf import Config

usage = """\
usage:
somabot.py (csv_file [--print-positions | --visual | --has-solution]
[--verbose | --quiet]) | --gui | --help | --info | --license | --version

csv_file: path to a file containing 27 3d coordinates, see the examples for\n\
more informations."""
version = '%prog ' + str(Config.version)[0:3]

parser = OptionParser(usage = usage, version = version)

default_msg = ' (default)'

# Action options

option_value = 'gui'
help_msg = 'launch the graphical user interface'

if not Config.gui_libs_loaded:
    help_msg = "Launch the graphical user interface. Warning : at least one of \
Tkinter, tkFileDialog, tkMessageBox is missing"

if Config.action == option_value:
    help_msg += default_msg

parser.add_option(
    '-g',
    '--gui',
    action = 'store_const',
    dest = 'action',
    const = option_value,
    default = Config.action,
    help = help_msg
)

option_value = 'info'
help_msg = "show the 7 pieces of the Soma's cube and exit (use it with a pager)"

if Config.action == option_value:
    help_msg += default_msg

parser.add_option(
    '-i',
    '--info',
    action = 'store_const',
    dest = 'action',
    const = option_value,
    help = help_msg
)

option_value = 'license'
help_msg = "show program's license and exit"

if Config.action == option_value:
    help_msg += default_msg

parser.add_option(
    '-l',
    '--license',
    action = 'store_const',
    dest = 'action',
    const = option_value,
    help = help_msg
)

# Result output options

group = OptionGroup(parser, 'Result output')

option_value = 'has'
help_msg = 'tell if the shape admits a solution'

if Config.print_solution == option_value:
    help_msg += default_msg

group.add_option(
    '-e',
    '--has-solution',
    action = 'store_const',
    dest = 'print_solution',
    default = Config.print_solution,
    const = 'has',
    help = help_msg
)

option_value = 'visual'
help_msg = 'show a 3D representation of the solution.'

if not Config.visual_loaded:
    help_msg = "Show a 3D representation of the solution. Warning : Visual \
Python not loaded."
    
if Config.print_solution == option_value:
    help_msg += default_msg
    
group.add_option(
    '-s',
    '--visual',
    action = 'store_const',
    dest = 'print_solution',
    const = 'visual',
    help = help_msg
)

option_value = 'coordinates'
help_msg = 'Print the coordinates of each piece.'

if Config.print_solution == option_value:
    help_msg += default_msg

group.add_option(
    '-p',
    '--print-positions',
    action = 'store_const',
    dest = 'print_solution',
    const = 'coordinates',
    help = help_msg
)

parser.add_option_group(group)
                 
# Verbosity control

group = OptionGroup(parser, 'Verbosity control')

option_value = True
help_msg = 'print status messages to stdout'

if Config.verbose == option_value:
    help_msg += default_msg

group.add_option(
    '-v',
    '--verbose',
    action = 'store_true',
    dest = 'verbose',
    default = Config.verbose,
    help = help_msg
)

option_value = False
help_msg = "don't print status messages to stdout"

if Config.verbose == option_value:
    help_msg += default_msg
    
group.add_option(
    '-q',
    '--quiet',
    action = 'store_false',
    dest = 'verbose',
    help = help_msg
)

parser.add_option_group(group)

(options, args) = parser.parse_args()

del option_value
del help_msg
del default_msg
del usage
del version

Config.action = options.action
Config.print_solution = options.print_solution
Config.verbose = options.verbose
